/*引入vue-*/
import { createRouter, createWebHashHistory } from "vue-router";
import { getChildrens } from "@/router/common";
import AdminLayout from "@/layouts/admin-layout";
import config from "@/config";

/*
 * meta元属性
 *
 * cache，代表页面是否缓存(true,缓存），默认不写为false
 * icon，菜单的图标（andt内置图标或者自定义的iconfont）
 * role，页面权限
 * menu，是否作为菜单，默认不写为true
 * name，默认的网页标题
 * */

//自动导入路由
const children = getChildrens();

//路由页面
let routes = [
  {
    path: "/",
    name: " ",
    meta: {
      role: 0,
    },
    redirect: config.index,
    component: AdminLayout,
    children: [
      {
        path: "dash",
        meta: {
          role: 2,
          name: "工作台",
        },
        component: () => import("@/layouts/admin-view.vue"),
        redirect: "/dash/data",
        children: children.工作台.default(),
      },
      {
        path: "list",
        meta: {
          role: 3,
          name: "资源素材",
        },
        component: () => import("@/layouts/admin-view.vue"),
        redirect: "/list/cat-list",
        children: children.资源素材.default(),
      },
      {
        path: "orders",
        meta: {
          role: 3,
          name: "订单管理",
        },
        component: () => import("@/layouts/admin-view.vue"),
        redirect: "/orders/online-order",
        children: children.订单管理.default(),
      },
      {
        path: "stores",
        meta: {
          role: 3,
          name: "门店管理",
        },
        component: () => import("@/layouts/admin-view.vue"),
        redirect: "/stores/stores-admin",
        children: children.门店管理.default(),
      },
      {
        path: "admin",
        meta: {
          role: 3,
          name: "系统管理",
        },
        component: () => import("@/layouts/admin-view.vue"),
        redirect: "/admin/staff",
        children: children.系统管理.default(),
      },
    ],
  },
  {
    path: "/export",
    meta: {
      role: 2,
      name: "图片导出",
    },
    component: () => import("@/pages/export"),
  },
  {
    path: "/login",
    meta: {
      role: 0,
      name: "登录",
    },
    component: () => import("@/pages/login"),
  },
  {
    path: "/403",
    meta: {
      role: 0,
      name: "403",
    },
    component: () => import("@/pages/error/403"),
  },
  {
    path: "/:pathMatch(.*)*",
    meta: {
      role: 0,
      name: "404",
    },
    component: () => import("@/pages/error/404"),
  },
];
console.log("routes", routes);

/*路由配置项*/
export const router = createRouter({
  history: createWebHashHistory(),
  routes,
});
